@@ -2,7 +2,7 @@
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -26,11 +26,15 @@
 #  endif /* no PROTOTYPES */
 #endif
 
-#include "darray.h"
+/* Functions mapped on file names. */
+typedef void (*filterdir_fun_t)
+  PARAMS ((const char *dir, const char *file, void *filtarg));
+
+/* Functions used to filter the file names to keep. */
+typedef bool (*filterdir_filter_t)
+  PARAMS ((const char *dir, const char *file, void *filtarg));
 
 void
-filterdir PARAMS ((const char *dir, struct darray * arr, 
-		   int (*filter) (const char *)));
-void
-filterdir_pattern PARAMS ((const char *dir, struct darray * arr, 
-			   const char * pattern));
+filterdir PARAMS ((const char *dir,
+		   filterdir_filter_t filter, void *filtarg,
+		   filterdir_fun_t fun, void *arg));
